@@ -7,6 +7,7 @@ from send2trash import send2trash
 import shutil
 import requests
 import os
+import sys
 from datetime import datetime
 
 import ttkbootstrap as ttk
@@ -15,12 +16,17 @@ from ttkbootstrap import utility
 from ttkbootstrap.dialogs.dialogs import Messagebox
 from ttkbootstrap.icons import Emoji
 from ttkbootstrap.toast import ToastNotification
-from toastx import ToastNotificationX
+
+if __package__:
+    from .toastx import ToastNotificationX
+else:
+    sys.path.append(os.path.dirname(__file__))
+    from toastx import ToastNotificationX
 
 USE_PROGRESSBAR = False
 USE_GRID_LAYOUT = False
 DEFAULT_WINSIZE = '500x400'
-ENABLE_FULLSCREEN = False
+ENABLE_FULLSCREEN = True
 TREEVIEW_ROW_HEIGHT = 21
 VERBOSE = False
 
