@@ -1,4 +1,11 @@
-import RPi.GPIO as GPIO
+import sys
+import os.path
+if sys.platform == 'win32':
+    sys.path.append(os.path.dirname(__file__))
+    from simulator import GPIO
+else:
+	from RPi.GPIO import GPIO
+
 import time
 import sys
 import os.path
